@@ -1,5 +1,8 @@
-naive <- function(x, block.vars, id.vars, vcov, n.tr, l2, l1names, valid, validvar, validlb, validub, verbose, ismahal, dist){
+naive <- function(x, block.vars, id.vars, vcov, n.tr, l2, l1names, 
+                  valid, validvar, validlb, validub, verbose, ismahal, dist){
+  
   vcd <- as.matrix(x[, block.vars])
+  
   if(nrow(vcd) == 1){
     result <- data.frame(matrix(c(x[, id.vars], rep(NA, n.tr)), ncol = n.tr + 1))
   }
@@ -30,8 +33,12 @@ naive <- function(x, block.vars, id.vars, vcov, n.tr, l2, l1names, valid, validv
               ismahal = as.integer(ismahal),
               result = integer(p * n.tr), 
               p = as.integer(p))
+    
+    result <- data.frame(matrix(out$result, 
+                                ncol=(n.tr), 
+                                byrow = TRUE), 
+                         out$pairdist)
 
-    result <- data.frame(matrix(out$result, ncol=(n.tr), byrow = TRUE), out$pairdist)
   }
   return(result)
 }
