@@ -13,7 +13,7 @@ void optgreed(double *data,
 	      int *nrow,
 	      int *ncol,
 	      double *vcovi,
-	      int *ntr,
+	      unsigned int *ntr,
 	      int *l2,
 	      int *l1names,
 	      int *valid,
